package vue;

// Java emulation core implementation
class JavaVUE extends VUE {

    // Instance fields
    private byte[] rom; // Cartridge ROM



    ///////////////////////////////////////////////////////////////////////////
    //                             Constructors                              //
    ///////////////////////////////////////////////////////////////////////////

    // Default constructor
    JavaVUE() {
        rom = new byte[1024];
    }



    ///////////////////////////////////////////////////////////////////////////
    //                            Public Methods                             //
    ///////////////////////////////////////////////////////////////////////////

    // Release any used resources
    public void dispose() { }; // No action needed

    // Retrieve a copy of the ROM data
    public byte[] getROM() {
        var ret = new byte[rom.length];
        System.arraycopy(rom, 0, ret, 0, rom.length);
        return ret;
    }

    // Determine whether the context is native-backed
    public boolean isNative() {
        return false;
    }

    // Provide new ROM data
    public boolean setROM(byte[] data, int offset, int length) {

        // Error checking
        if (data == null || offset < 0 || length < 1024 ||
            offset + length > data.length || (length & length - 1) != 0)
            return false;

        // Accept the new ROM data
        rom = new byte[length];
        System.arraycopy(data, offset, rom, 0, length);
        return true;
    }

}
