package vue;

// Template for emulation core implementations
public abstract class VUE {

    // Static fields
    private static String nativeID = null; // ID of loaded native library



    ///////////////////////////////////////////////////////////////////////////
    //                               Static Methods                          //
    ///////////////////////////////////////////////////////////////////////////

    // Produce an emulation core context
    public static VUE create(boolean useNative) {
        return !useNative ? new JavaVUE() :
            isNativeLoaded() ? new NativeVUE() : null;
    }

    // Retrieve the ID of the loaded native library, if any
    public static String getNativeID() {
        return nativeID;
    }

    // Determine whether the native module is loaded
    public static boolean isNativeLoaded() {
        return nativeID != null;
    }

    // Specify the ID of the loaded native library
    public static void setNativeID(String nativeID) {
        VUE.nativeID = nativeID;
    }



    ///////////////////////////////////////////////////////////////////////////
    //                            Public Methods                             //
    ///////////////////////////////////////////////////////////////////////////

    // Release any used resources
    public abstract void dispose();

    // Retrieve a copy of the ROM data
    public abstract byte[] getROM();

    // Determine whether the context is native-backed
    public abstract boolean isNative();

    // Provide new ROM data
    public abstract boolean setROM(byte[] data, int offset, int length);

}
